Installation — Meta Package Manager 2.3.0 documentation

# Installation

This package is available on PyPi, so you can install the latest stable release and its dependencies with a simple `pip` call:

    $ pip install meta-package-manager

See also pip installation instructions.

Warning

`mpm`, the Python module, is not the same as `meta-package-manager`. Only the later provides the `mpm` CLI per-se. The former has nothing to do with the current project.